<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Fett</translation>
    </message>
    <message>
        <location filename="../../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
</context>
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../../ui_obconf.h" line="1012"/>
        <source>Window Manager Preferences</source>
        <translation>Fenstermanager Openbox :: Einstellungen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1017"/>
        <source>Theme</source>
        <translation>Thema</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1019"/>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1021"/>
        <source>Font</source>
        <translation>Schrift</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1023"/>
        <location filename="../../ui_obconf.h" line="1038"/>
        <source>Windows</source>
        <translation>Fenster</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1025"/>
        <source>Move &amp; Resize</source>
        <translation>Verschieben und Größe ändern</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1027"/>
        <source>Mouse</source>
        <translation>Maus</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1029"/>
        <source>Desktops</source>
        <translation>Arbeitsflächen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1031"/>
        <source>Margins</source>
        <translation>Ränder</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1033"/>
        <source>Dock</source>
        <translation>Dock</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1036"/>
        <source>&amp;Install a new theme...</source>
        <translation>Neues Thema &amp;installieren...</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1037"/>
        <source>Create a theme &amp;archive (.obt)...</source>
        <translation>Themenarchiv &amp;erstellen (.obt)...</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1039"/>
        <source>&amp;Windows retain a border when undecorated</source>
        <translation>Undekorierte Fenster um&amp;randen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1040"/>
        <source>A&amp;nimate iconify and restore</source>
        <translation>Minimieren und Wiederherstellen &amp;animieren</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1041"/>
        <source>Window Titles</source>
        <translation>Fenstertitel</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1042"/>
        <source>Button order:</source>
        <translation>Anordnung der Schaltflächen (Knöpfe):</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1043"/>
        <source>N: Window icon
L: Window label (Title)
I: Iconify (Minimize)
M: Maximize
C: Close
S: Shade (Roll up)
D: Omnipresent (On all desktops)</source>
        <translation>N: Fenstersymbol
L: Fenstertitel
I: Minimieren
M: Maximieren
C: Schließen
S: Einrollen
D: auf allen Arbeitsflächen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1056"/>
        <source>&amp;Active window title: </source>
        <translation>Fenstertitel &amp;aktives Fenster</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1057"/>
        <source>&amp;Inactive window title: </source>
        <translation>Fenstertitel &amp;inaktives Fenster</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1058"/>
        <source>Menu &amp;header: </source>
        <translation>Menü - &amp;Überschrift</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1059"/>
        <source>&amp;Menu Item: </source>
        <translation>Menü - einzelne &amp;Einträge</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1060"/>
        <source>Active &amp;On-screen display: </source>
        <translation>A&amp;ktive Bildschirmanzeige</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1061"/>
        <source>Inactive O&amp;n-screen display: </source>
        <translation>I&amp;naktive Bildschirmanzeige</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1062"/>
        <source>Focus &amp;new windows when they appear</source>
        <translation>&amp;Neue Fenster beim Erscheinen fokussieren</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1063"/>
        <source>&amp;Place new windows under the mouse pointer</source>
        <translation>Neue Fenster unter dem Mauszeiger &amp;platzieren</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1064"/>
        <source>&amp;Center new windows when they are placed</source>
        <translation>Neue Fenster &amp;zentrieren</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1065"/>
        <source>Prefer to place new windows &amp;on:</source>
        <translation>Neue Fenster &amp;vorzugsweise platzieren auf</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1068"/>
        <source>All monitors</source>
        <translation>allen Bildschirmen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1069"/>
        <source>The active monitor</source>
        <translation>dem aktiven Bildschirm</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1070"/>
        <source>The monitor with the mouse</source>
        <translation>dem Bildschirm, wo sich der Mauszeiger befindet</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1071"/>
        <source>Primary monitor</source>
        <translation>dem primären Bildschirm</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1073"/>
        <source>Primary Monitor</source>
        <translation>Primärer Bildschirm</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1074"/>
        <source>The primary monitor is where Openbox will place dialogs, such as the one used for cycling windows.</source>
        <translation>Der primäre Bildschirm ist derjenige, auf dem Dialoge wie der zum Wechsel von Fenstern angezeigt werden.</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1075"/>
        <source>Primary &amp;monitor:</source>
        <translation>P&amp;rimärer Bildschirm</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1078"/>
        <source>Fixed Monitor</source>
        <translation>Festgelegter Bildschirm</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1079"/>
        <source>Active Monitor</source>
        <translation>aktiver Bildschirm</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1080"/>
        <source>Monitor With Mouse Pointer</source>
        <translation>Bildschirm, wo sich der Mauszeiger befindet</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1082"/>
        <source>&amp;Fixed monitor:</source>
        <translation>&amp;Festgelegter Bildschirm</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1083"/>
        <source>Moving and Resizing Windows</source>
        <translation>Verschieben und Größenänderung von Fenstern</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1084"/>
        <source>Update the window contents while &amp;resizing</source>
        <translation>Fensterinhalt während &amp;Größenänderungen anzeigen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1085"/>
        <source>Drag &amp;threshold distance:</source>
        <translation>Abstand beim &amp;Verschieben</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1086"/>
        <source>Amount of resistance against other &amp;windows:</source>
        <translation>Widerstand gegenüber anderen &amp;Fenstern</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1087"/>
        <source>Amount of resistance against screen &amp;edges:</source>
        <translation>Widerstand gegenüber &amp;Bildschirmrändern</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1088"/>
        <source>&amp;Amount of time to wait before switching:</source>
        <translation>Ver&amp;zögerung vor dem Arbeitsflächenwechsel</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1089"/>
        <source>&amp;Switch desktops when moving a window past the screen edge</source>
        <translation>Arbeitsfläche beim Verschieben des Fensters über ihren Rand &amp;wechseln</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1090"/>
        <source>Information Dialog</source>
        <translation>Informationsdialog</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1093"/>
        <location filename="../../ui_obconf.h" line="1100"/>
        <source>Centered</source>
        <translation>Fenstermitte</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1094"/>
        <source>From left edge</source>
        <translation>Vom linken Rand</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1095"/>
        <source>From right edge</source>
        <translation>Vom rechten Rand</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1097"/>
        <source>Fixed &amp;y position:</source>
        <translation>Festgelegte &amp;y-Position (Pixel)</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1101"/>
        <source>From top edge</source>
        <translation>Vom oberen Rand</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1102"/>
        <source>From bottom edge</source>
        <translation>Vom unteren Rand</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1104"/>
        <source>Information dialog&apos;s &amp;position:</source>
        <translation>&amp;Position des Informationsdialogs</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1105"/>
        <source>Fixed &amp;x position:</source>
        <translation>Festgelegte &amp;x-Position (Pixel)</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1106"/>
        <source>Show &amp;information dialog:</source>
        <translation>&amp;Informationsdialog anzeigen:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1109"/>
        <source>When resizing terminal windows</source>
        <translation>Bei Größenänderung von Terminalfenstern</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1110"/>
        <source>Always</source>
        <translation>Immer</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1111"/>
        <source>Never</source>
        <translation>Nie</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1115"/>
        <source>Centered on the window</source>
        <translation>Fenstermitte</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1116"/>
        <source>Above the window</source>
        <translation>Oberhalb des Fensters</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1117"/>
        <source>Fixed position on screen</source>
        <translation>Feste Position auf dem Bildschirm</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1119"/>
        <source>Focusing Windows</source>
        <translation>Fokussieren von Fenstern</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1120"/>
        <source>Focus windows when the mouse pointer moves over them</source>
        <translation>Fenster &amp;fokussieren, wenn sich der Mauszeiger über ihnen befindet</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1121"/>
        <source>&amp;Delay before focusing and raising windows:</source>
        <translation>&amp;Verzögerung vor dem Fokussieren und Hervorheben</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1122"/>
        <source>Move focus under the mouse when &amp;switching desktops</source>
        <translation>Beim &amp;Wechsel von Arbeitsflächen Fokus unter den Mauszeiger bringen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1123"/>
        <source>Move focus &amp;under the mouse when the mouse is not moving</source>
        <translation>Fokus &amp;unter die Maus bringen, wenn diese nicht bewegt wird</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1124"/>
        <source>&amp;Raise windows when the mouse pointer moves over them</source>
        <translation>Fenster &amp;hervorheben, wenn sich der Mauszeiger darüber befindet</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1125"/>
        <source>Titlebar</source>
        <translation>Fenstertitel</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1126"/>
        <source>Double click on the &amp;titlebar:</source>
        <translation>Doppelklick auf den Fenster&amp;titel</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1129"/>
        <source>Maximizes the window</source>
        <translation>Maximiert das Fenster</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1130"/>
        <source>Shades the window</source>
        <translation>Rollt das Fenster ein</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1132"/>
        <source>Double click ti&amp;me:</source>
        <translation>&amp;Intervall für Doppelklick</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1133"/>
        <source>&amp;Show a notification when switching desktops</source>
        <translation>Benachrichtigung beim Arbeitsflächen&amp;wechsel anzeigen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1134"/>
        <source>&amp;Amount of time to show the notification for:</source>
        <translation>&amp;Dauer, für die die Benachrichtigung angezeigt wird</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1135"/>
        <source>&amp;Number of desktops: </source>
        <translation>An&amp;zahl an Arbeitsflächen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1136"/>
        <source>&amp;Desktop names:</source>
        <translation>&amp;Bezeichnungen der Arbeitsflächen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1137"/>
        <source>Desktop Margins</source>
        <translation>Arbeitsflächenränder</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1138"/>
        <source>Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.</source>
        <translation>Arbeitsflächenränder sind reservierte Bereiche am Rand des Bildschirms. Neue Fenster werden dort nicht platziert und maximierte Fenster überdecken diese Bereiche nicht.</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1139"/>
        <source>Left:</source>
        <translation>Links</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1140"/>
        <location filename="../../ui_obconf.h" line="1142"/>
        <location filename="../../ui_obconf.h" line="1144"/>
        <location filename="../../ui_obconf.h" line="1146"/>
        <source>px</source>
        <translation>Pixel (px)</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1141"/>
        <source>Top:</source>
        <translation>Oben</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1143"/>
        <source>Right:</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1145"/>
        <source>Bottom:</source>
        <translation>Unten</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1147"/>
        <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
        <translation>Das &quot;dock&quot; ist ein graphisches Objekt zum Vorhalten sogenannter dock-Anwendungen (&quot;dockapps&quot;), die z. B. eine Uhr oder Benachrichtigungen anzeigen können.
Das dock wird erst nach dem Starten von dockapps sichtbar.</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1148"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1149"/>
        <source>&amp;Position:</source>
        <translation>&amp;Position:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1152"/>
        <source>Top Left</source>
        <translation>oben links</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1153"/>
        <source>Top</source>
        <translation>oben zentriert</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1154"/>
        <source>Top Right</source>
        <translation>oben rechts</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1155"/>
        <source>Left</source>
        <translation>mitte (vertikal) links</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1156"/>
        <source>Right</source>
        <translation>mitte (vertikal) rechts</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1157"/>
        <source>Bottom Left</source>
        <translation>unten rechts</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1158"/>
        <source>Bottom</source>
        <translation>unten zentriert</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1159"/>
        <source>Bottom Right</source>
        <translation>unten rechts</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1160"/>
        <source>Floating</source>
        <translation>manuell festgelegte Position</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1162"/>
        <source>&amp;Floating position:</source>
        <translation>&amp;manuell festgelegte Position</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1163"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1164"/>
        <source>Allow &amp;windows to be placed within the dock&apos;s area</source>
        <translation>Positionieren von &amp;Fenstern über dem dock erlauben</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1165"/>
        <source>&amp;Orientation: </source>
        <translation>Ausrichtung</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1168"/>
        <source>Vertical</source>
        <translation>vertikal</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1169"/>
        <source>Horizontal</source>
        <translation>horizontal</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1171"/>
        <source>Stacking</source>
        <translation>Ebenen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1172"/>
        <source>Keep dock &amp;above other windows</source>
        <translation>immer im &amp;Vordergrund</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1173"/>
        <source>A&amp;llow dock to be both above and below windows</source>
        <translation>analog &amp;regulären Fenstern (Vorder- und Hintergrund möglich)</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1174"/>
        <source>Keep dock &amp;below other windows</source>
        <translation>immer im &amp;Hintergrund</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1175"/>
        <source>Hiding</source>
        <translation>Ausblenden</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1176"/>
        <source>&amp;Delay before hiding:</source>
        <translation>Verzögerung vor dem &amp;Ausblenden</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1177"/>
        <source>Delay before &amp;showing:</source>
        <translation>Verzögerung vor dem &amp;Einblenden</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1178"/>
        <source>&amp;Hide off screen</source>
        <translation>Ausblenden a&amp;ktivieren</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1179"/>
        <source>About</source>
        <translation>&amp;Über ObConf-Qt</translation>
    </message>
</context>
<context>
    <name>Obconf::MainDialog</name>
    <message>
        <location filename="../../theme.cpp" line="150"/>
        <location filename="../../theme.cpp" line="160"/>
        <source>Choose an Openbox theme</source>
        <translation>Auswahl des Openbox Themas</translation>
    </message>
    <message>
        <location filename="../../desktops.cpp" line="65"/>
        <location filename="../../desktops.cpp" line="87"/>
        <location filename="../../desktops.cpp" line="99"/>
        <source>(Unnamed desktop)</source>
        <translation>(Unbenannte Arbeitsfläche)</translation>
    </message>
    <message>
        <location filename="../../mouse.cpp" line="57"/>
        <source>Custom actions</source>
        <translation>Benutzerdefinierte Aktionen</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="76"/>
        <source>About ObConf-Qt</source>
        <translation>Über ObConf-Qt</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="77"/>
        <source>A preferences manager for Openbox

Copyright (c) 2014-2015

Authors:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

The program is based on ObConf developed by the following developers.
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
        <translation>graphische Benutzeroberfläche zur Konfiguration des Fenstermanagers Openbox

Copyright (c) 2014-2015

Autor:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

Das Programm basiert auf ObConf, entwickelt von
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</translation>
    </message>
    <message>
        <source>A preferences manager for Openbox

Copyright (c) 2003-2013

Authors:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
        <translation type="vanished">graphische Benutzeroberfläche zur Konfiguration des Fenstermanagers Openbox

Copyright (c) 2003-2013

Autoren:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../archive.cpp" line="26"/>
        <source>&quot;%1&quot; was installed to %1</source>
        <translation>&quot;%1&quot; wurde nach %1 installiert</translation>
    </message>
    <message>
        <location filename="../../archive.cpp" line="53"/>
        <source>&quot;%1&quot; was successfully created</source>
        <translation>&quot;%1&quot; wurde erfolgreich erstellt</translation>
    </message>
    <message>
        <location filename="../../archive.cpp" line="89"/>
        <source>Unable to create the theme archive &quot;%1&quot;.
The following errors were reported:
%2</source>
        <translation>Erstellung des Themenarchivs &quot;%1&quot; ist fehlgeschlagen.
        Die folgenden Fehlermeldungen wurden mitgeteilt:
        %2</translation>
    </message>
    <message>
        <location filename="../../archive.cpp" line="95"/>
        <location filename="../../archive.cpp" line="178"/>
        <source>Unable to run the &quot;tar&quot; command: %1</source>
        <translation>&quot;tar&quot; Befehl %1 kann nicht ausgeführt werden</translation>
    </message>
    <message>
        <location filename="../../archive.cpp" line="115"/>
        <source>Unable to create directory &quot;%1&quot;: %2</source>
        <translation>Verzeichnis &quot;%1&quot; kann nicht erstellt werden: %2</translation>
    </message>
    <message>
        <location filename="../../archive.cpp" line="138"/>
        <source>&quot;%1&quot; does not appear to be a valid Openbox theme directory</source>
        <translation>&quot;%1&quot; scheint kein korrektes Themenverzeichnis von Openbox zu sein</translation>
    </message>
    <message>
        <location filename="../../archive.cpp" line="148"/>
        <source>Unable to move to directory &quot;%1&quot;: %2</source>
        <translation>Verzeichnis &quot;%1&quot; kann nicht verschoben werden: %2</translation>
    </message>
    <message>
        <location filename="../../archive.cpp" line="185"/>
        <source>Unable to extract the file &quot;%1&quot;.
Please ensure that &quot;%2&quot; is writable and that the file is a valid Openbox theme archive.
The following errors were reported:
%3</source>
        <translation>Datei &quot;%1&quot; kann nicht entpackt werden.
        Bitte sicherstellen, dass &quot;%2&quot; beschrieben werden kann und die Datei ein korrektes Archiv mit einem Openbox Thema ist.
        Folgende Fehlermeldungen wurden mitgeteilt:
        %3</translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="53"/>
        <source>ObConf Error</source>
        <translation>ObConf-Qt Fehler</translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="58"/>
        <source>Copyright (c) 2003-2008   Dana Jansens
Copyright (c) 2003        Tim Riley
Copyright (c) 2007        Javeed Shaikh
Copyright (c) 2013        Hong Jen Yee (PCMan)

This program comes with ABSOLUTELY NO WARRANTY.
This is free software, and you are welcome to redistribute it
under certain conditions. See the file COPYING for details.

</source>
        <translation>Copyright (c) 2003-2008   Dana Jansens
Copyright (c) 2003        Tim Riley
Copyright (c) 2007        Javeed Shaikh
Copyright (c) 2013        Hong Jen Yee (PCMan)

Dieses Programm wird unter Ausschluss jeglicher Garantie zur Verfügung
gestellt.
Es handelt sich um freie Software,die unter Beachtung bestimmter
Voraussetzungen gerne weitergegeben werden darf, Näheres enthält die
Datei COPYING.

</translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="73"/>
        <source>Syntax: obconf [options] [ARCHIVE.obt]

Options:
  --help                Display this help and exit
  --version             Display the version and exit
  --install ARCHIVE.obt Install the given theme archive and select it
  --archive THEME       Create a theme archive from the given theme directory
  --config-file FILE    Specify the path to the config file to use
</source>
        <translation>Übersicht: obconf [Optionen] [ARCHIVE.obt]

Optionen:
  --help                diesen Hilfetext ausgeben und Programm beenden
  --version             Version ausgeben und Programm beenden
  --install ARCHIVE.obt Thema aus angegebenem Archiv extrahieren und verwenden
  --archive THEMA       Archiv mit dem im genannten Verzeichnis befindlichen Thema erstellen
  --config-file DATEI   zu verwendende Konfigurationsdatei explizit angeben
  </translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="97"/>
        <source>--install requires an argument
</source>
        <translation>--install benötigt ein Argument</translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="103"/>
        <source>--archive requires an argument
</source>
        <translation>--archive benötigt ein Argument</translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="109"/>
        <source>--config-file requires an argument
</source>
        <translation>--config-file benötigt ein Argument</translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="239"/>
        <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.

Message: %1</source>
        <translation>Fehler bei der Auswertung der Konfigurationsdatei von Openbox. Die Konfigurationsdatei ist nicht in korrekter XML verfasst.</translation>
    </message>
    <message>
        <source>--archive requires an argument</source>
        <translation type="vanished">--archive benötigt ein Argument</translation>
    </message>
    <message>
        <source>--config-file requires an argument</source>
        <translation type="vanished">--config-file benötigt ein Argument</translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="225"/>
        <location filename="../../obconf-qt.cpp" line="241"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="226"/>
        <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
        <translation>Datei rc.xml konnte nicht geladen werden. Möglicher Weise wurde Openbox nicht korrekt installiert.</translation>
    </message>
    <message>
        <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.

        Message: %1</source>
        <translation type="vanished">Fehler bei der Verarbeitung der Konfigurationsdatei von Openbox. Die genannte Datei ist kein korrektes XML.
        
        Fehlermeldung: %1</translation>
    </message>
</context>
</TS>
